@@ -4,7 +4,7 @@ use warnings;
 
 package App::colourhexdump;
 
-our $VERSION = '1.000000';
+our $VERSION = '1.000001';
 
 # ABSTRACT: HexDump, but with character-class highlighting.
 
@@ -19,32 +19,6 @@ use Term::ANSIColor 3.00 qw( colorstrip );
 use App::colourhexdump::Formatter;
 use namespace::autoclean;
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 has colour_profile => (
   metaclass     => 'Getopt',
   isa           => 'Str',
@@ -204,7 +178,7 @@ App::colourhexdump - HexDump, but with character-class highlighting.
 
 =head1 VERSION
 
-version 1.000000
+version 1.000001
 
 =head1 SYNOPSIS
 
@@ -224,9 +198,9 @@ It can be used like so
 
 If you are using an HTML-enabled POD viewer, you should see a screenshot of this in action:
 
-( Everyone else can visit L<http://kentfredric.github.io/App-colourhexdump/media/Screenshot.png> )
+( Everyone else can visit L<http://kentnl.github.io/App-colourhexdump/media/Screenshot.png> )
 
-=for html <center><img src="http://kentfredric.github.io/App-colourhexdump/media/Screenshot.png" alt="Screenshot with explanation of colours" width="826" height="838"/></center>
+=for html <center><img src="http://kentnl.github.io/App-colourhexdump/media/Screenshot.png" alt="Screenshot with explanation of colours" width="826" height="838"/></center>
 
 =head1 METHODS
 
